@@ -5,10 +5,11 @@
 #include <netinet/in.h>
 #include <netdb.h>
 #include <arpa/inet.h>
-#include <sys/un.h>
 #include <sys/time.h>
 #include <fcntl.h>
 
+extern int errno;
+
 #ifdef SOLARIS
 #define bzero(s, n) (memset((s), 0, (n)))
 #endif
@@ -53,35 +54,27 @@ int main(argc, argv)
 int argc;
 char *argv[];
 {
-    int fd, info;
-    int port;
+    int fd, port, leng;
     char buffer[4096], host[128];
-    int l, tl = 0, ntl, pid, out;
+    int l, tl = 0, ntl, pid, out, elt;
     time_t st;
 
-    if ((l = fork()) != 0) 
-    {
-	printf("%d\n", l);
-	fclose(stdout);
-	exit(0);
-    }
-    (void) close(1);
-    (void) close(2);
-    gethostname(host, 128);
     pid = getpid();
+    printf("%d\n", pid);
+    fflush(stdout);
+    gethostname(host, 128);
     port = atoi(argv[2]);
+    leng = atoi(argv[6]);
     if ((fd = doConnect(argv[1], port)) < 0 )
     {
+	printf("%d DCCError Get %s from %s connection failed %d.\n", pid, argv[3], 
+	  argv[5], errno);
+	fclose(stdout);
 	exit(1);
     }
-    if ((info = doConnect(host, atoi(argv[4]))) < 0 )
-    {
-	(void) shutdown(fd, 2);
-	(void) close(fd);
-	exit(1);
-    }
-    sprintf(host, "%d DCC Get connection to %s established.\n", pid, argv[5]);
-    send(info, host, strlen(host), 0);
+    
+    printf("%d DCC Get connection to %s established.\n", pid, argv[5]);
+    fflush(stdout);
     st = time((time_t *) 0);
     l = -1;
     if ((out = open(argv[3], O_WRONLY | O_CREAT | O_TRUNC, 0600)) >= 0)
@@ -89,10 +82,16 @@ char *argv[];
 	while ((l = read(fd, buffer, 4096)) > 0) 
 	{
 	    tl += l;
+	    elt = (int) ((leng - tl) / (((float) tl /(time((time_t*) 0) - st))));
+	    
+	    printf("%d DCC Get progress to %s %d %2.1f %d %d\n",
+	      fd, argv[5], tl, ((float) tl / (float) leng) * 100.0,
+	      elt / 60,  elt % 60);
+	    fflush(stdout);
 	    if (write(out, buffer, l) != l) 
 	    {
 		sprintf(host,
-		  "%d DCC Get: %s from %s Write error on output.\n", pid,
+		  "%d DCCError Get: %s from %s Write error on output.\n", pid,
 		  argv[3], argv[5]);
 		l = -1;
 		break;
@@ -101,7 +100,7 @@ char *argv[];
 	    if (write(fd, (char *) &ntl, sizeof(int)) != sizeof(int))
 	    {
 		sprintf(host,
-		  "%d DCC Get: %s from %s Write error on transfer.\n", pid,
+		  "%d DCCError Get: %s from %s Write error on transfer.\n", pid,
 		  argv[3], argv[5]);
 		l = -1;
 		break;
@@ -111,7 +110,7 @@ char *argv[];
     else
     {
 	sprintf(host,
-	  "%d DCC Get: %s from %s Cannot create output file.\n", pid,
+	  "%d DCCError Get: %s from %s Cannot create output file.\n", pid,
 	  argv[3], argv[5]);
     }
     (void) close(out);
@@ -121,6 +120,12 @@ char *argv[];
     {
 	(void) unlink(argv[3]);
     }
+    else if (tl != leng)
+    {
+	sprintf(host,
+	  "%d DCCError Get: %s from %s Transfer interrupted.\n", pid,
+	  argv[3], argv[5]);
+    }
     else 
     {
 	if ((st = time((time_t *) 0) - st) == 0)
@@ -130,8 +135,7 @@ char *argv[];
 	sprintf(host, "%d DCC Get: %s from %s completed. %f Kbytes/sec\n", pid,
 	    argv[3], argv[5], ((float) tl /1000.0) / (float) st);
     }
-    send(info, host, strlen(host), 0);
-    (void) shutdown(info, 2);
-    (void) close(info);
+    printf("%s", host);
+    fclose(stdout);
     exit(0);
 }
