@@ -1,7 +1,7 @@
 #
-# $Source: /user/nlfm/Working/Zircon/Development/lib/RCS/Topic.tcl,v $
-# $Date: 1994/02/11 13:41:31 $
-# $Revision: 1.15.1.2 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Topic.tcl,v $
+# $Date: 1996/08/29 11:33:49 $
+# $Revision: 1.17.1.5 $
 #
 #
 # Topic handling procs
@@ -9,6 +9,7 @@
 proc keepTopic {this value} {
     if ![string match {} $value] {
 	set chan [$this name]
+	regsub -all "\[\r\n\]" $value {} value
 	$this configure -topic $value
 	set t [$this topics]
 	if {[lsearch $t $value] < 0} {
@@ -23,22 +24,25 @@ proc keepTopic {this value} {
 }
 #
 proc getTopic {this} {
+    global ztrans
     set chan [$this name]
-    mkEntryBox .@topic "${chan} Topic" "Enter your new topic for ${chan}:" \
-      {{Topic {}}} "OK {$this configure -topic}" \
-      "Keep {keepTopic $this}" {Cancel {}}
+    mkEntryBox .@tp$this "$chan Topic" "Enter your new topic for $chan:" \
+      "{$ztrans(topic) {}}" "$ztrans(ok) {$this configure -topic}" \
+      "$ztrans(keep) {keepTopic $this}" "$ztrans(cancel) {}"
 }
 #
 proc sendTopic {win} {
-    if [normal $win] {
-	[channel $win] configure -topic [$win get 1.0 end]
-    }
+    if [normal $win] {[channel $win] configure -topic [$win get 1.0 end]}
 }
 #
 proc irc331 {net prefix param pargs} {
-    [Channel :: find [lindex $pargs 1]] setTopic {}
+    if [string compare [set chn [Channel :: find [lindex $pargs 1]]] nil] {
+	$chn setTopic {}
+    }
 }
 #
 proc irc332 {net prefix param pargs} {
-    [Channel :: find [lindex $pargs 1]] setTopic $param
+    if [string compare [set chn [Channel :: find [lindex $pargs 1]]] nil] {
+	 $chn setTopic $param
+    }
 }
