@@ -1,20 +1,32 @@
 #
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/Window.tcl,v $
+# $Date: 1996/06/04 08:37:39 $
+# $Revision: 1.17.1.1 $
+#
+#
+class Window {
+    name	{}
+    icon	{}
+    iconbm	{}
+}
+#
 proc Window {name args} {
-    global WTO Wname
+    global WTO
     set ln [string tolower $name]
-    set this [newName Window]
+    set this [objName Window]
+    initObj $this Window
     set WTO($ln) $this
-    set Wname($this) $ln
-    proc $this {args} " eval window_call $this \$args "
+    upvar #0 $this wdata
+    set wdata(name) $ln
+    proc $this {args} "eval window_call $this \$args"
     toplevel $ln -class Zircon
     return $this
 }
 #
 proc window_call {this op args} {
-    switch $op {
-    name { global Wname ; return $Wname($this) }
-    default { eval window_$op $this $args }
-    }
+    upvar #0 $this wdata
+    if [info exists wdata($op)] { return $wdata($op) }
+    return [eval window_$op $this $args]
 }
 #
 proc window_setIcon {this chan title} {
@@ -30,19 +42,18 @@ proc window_setIcon {this chan title} {
 }
 #
 proc window_popup {this} {
-   set w [$this name]
-   wm $w deiconify
+   wm [set w [$this name]] deiconify
    raise $w
 }
 #
 proc window_delete {this} {
-    global WTO Icon IconBM
+    global WTO Icon IconBM Otype
     set w [$this name]
     bind $w.cFrm <Destroy> {}
     catch {unset WTO($w) Icon($w) IconBM($w)}
-    foreach v {OType Wname} {
-	global $v ; catch {unset ${v}($this)}
-    }
+    foreach v {OType } { catch {unset ${v}($this)} }
+    upvar #0 $this wdata
+    unset wdata
     rename $this {}
     destroy $w
 }
@@ -50,6 +61,7 @@ proc window_delete {this} {
 proc window_iconify {this} { wm iconify [$this name] }
 #
 proc window_configure {this args} {
+    upvar #0 $this wdata
     while {![string match {} $args]} {
 	set val [lindex $args 1]
 	set name [lindex $args 0]
@@ -58,15 +70,32 @@ proc window_configure {this args} {
 	-title -
 	-iconname -
 	-iconbitmap { wm $opt [$this name] $val }
+	-geometry -
 	-grid -
+	-resizable -
+	-maxsize -
 	-minsize { eval wm $opt [$this name] $val }
-	-*  { setGlob "C$opt" $this $val }
+	-*  { set wdata($opt) $val }
 	}
 	set args [lrange $args 2 end]
     }
 }
 #
-proc window_build {args} {
+proc window_build {this args} {
+    upvar #0 $this wdata
+    set w $wdata(name)
+    frame $w.f1
+    set f [frame $w.f2 -borderwidth 0]
+    label $f.label -text {} -width 10
+    pack $f.label -side left
+    set f [frame $f.cmdLine -borderwidth 0]
+    scrollbar $f.cscroller -orient horizontal -command "$f.commandLine xview"
+    emacsEntry $f.commandLine -xscrollcommand "$f.cscroller set"
+    pack $f.commandLine $f.cscroller -expand 1 -fill x
+    pack $w.f2.cmdLine -side left -fill x -expand 1
+    pack $w.f1 -fill both -expand 1
+    pack $w.cmdLine -fill x -expand 1
+    
 }
 #
 proc Window_find {name} {
@@ -80,3 +109,10 @@ proc Window_make {name} {
     set ln [string tolower name]
     return [expr {[info exists WTO($ln)] ? $WTO($ln) : [Window $name]}]
 }
+
+
+
+
+
+
+
