@@ -1,16 +1,16 @@
 #
-# $Source: /home/catless/nlfm/Working/Zircon/Development/lib/RCS/zdraw.tcl,v $
-# $Date: 1994/09/07 14:43:57 $
-# $Revision: 1.15.1.8 $
+# $Source: /home/nlfm/Working/Zircon/Released/lib/RCS/zdraw.tcl,v $
+# $Date: 1996/07/11 14:12:27 $
+# $Revision: 1.17.1.6 $
 #
 proc zdraw {usr cmd} {
-    if {{nil} == [set this [find [lindex $cmd 0]]]} {
-	net0 display {} "Bad draw command - {$cmd}"
+    if ![string compare nil [set this [find [lindex $cmd 0]]]] {
+	[$usr net] inform "Bad draw command - {$cmd}"
 	return
     }
-    if {[$this draw]} {
+    if [$this draw] {
 	$this makeZDraw
-	set w .@zd${this}.pic.canvas
+	set w .@zd$this.pic.canvas
 	switch [set lnm [$usr lname]] {
 	all -
 	current { set lnm ,$v }
@@ -18,24 +18,17 @@ proc zdraw {usr cmd} {
 	switch [lindex $cmd 1] {
 	delete {
 		switch -exact -- [set v [string tolower [lindex $cmd 2]]] {
-		*all* {
-			global ${this}Op
-			if {[info exists [set ${this}Op($usr)]] &&
-			  [set ${this}Op($usr)]} {
-			    set v all
-			} {
-			    set v $lnm
-			}
-		    }
+		*all* {	if [$this isOp $usr] { set v all } { set v $lnm } }
 		all -
 		current { set v ,$v }
 		}
-		if {$v == {all} || $v == $lnm} { $w delete $v }
+		if {![string compare $v all] || ![string compare $v $lnm]} { $w delete $v }
 	    }
 	default {
-		regsub -all {[][$]} [lrange $cmd 1 end] {} dc
-		set tid [eval $w $dc]
-		$w itemconfigure $tid -tags $lnm
+		regsub -all {[][$;]} [lrange $cmd 1 end] {} dc
+		if ![catch {set tid [eval $w $dc]} msg] {
+		    $w itemconfigure $tid -tags $lnm
+		}
 	    }
 	}
     }
@@ -43,75 +36,54 @@ proc zdraw {usr cmd} {
 
 proc zdDestroy {win} {
     destroy $win
-    foreach v {ZDStart ZDPoints ZDMode ZDLast ZDFill ZDOln} {
-	global $v ; unset ${v}($win)
-    }
+    catch {uplevel #0 unset Z$win}
 }
 
 proc zdModeChange {type win} {
-    global ZDMode
-    if [info exists ZDMode($win)] {
-	$win.plt.$ZDMode(${win}) configure -relief raised
-    }
-    set ZDMode(${win}) $type
-    foreach v {ZDStart ZDLast ZDPoints} {
-	global $v
-	set ${v}(${win}) {}
+    upvar #0 Z$win zdata
+    if [info exists zdata(mode)] {
+	$win.plt.$zdata(mode) configure -relief raised
     }
+    set zdata(mode) $type
+    foreach v {start last points} { set zdata($v) {} }
     $win.pic.canvas delete @r
     $win.pic.canvas delete @p
     $win.plt.$type configure -relief sunken
 }
 
-if {[tk colormodel .] != "monochrome"} {
 proc clButtons win {
     global zircon
     button $win.oln.none -bitmap @$zircon(lib)/bitmaps/none.xbm \
-      -command "zdColChange ZDOln $win oln none" -relief raised \
+      -command "zdColChange oln $win oln none" -relief raised \
       -height 24 -width 24
     button $win.fill.none -bitmap @$zircon(lib)/bitmaps/none.xbm \
-      -command "zdColChange ZDFill $win fill none" -relief raised \
+      -command "zdColChange fill $win fill none" -relief raised \
       -height 24 -width 24
     pack $win.oln.none -side left -expand 1 -fill x
     pack $win.fill.none -side left -expand 1 -fill x
     foreach cl {black white red orange yellow green blue violet} {
 	button $win.oln.$cl -background $cl \
-	  -command "zdColChange ZDOln $win oln $cl" \
+	  -command "zdColChange oln $win oln $cl" \
 	  -relief raised
 	button $win.fill.$cl \
-	  -background $cl -command "zdColChange ZDFill $win fill $cl" \
+	  -background $cl -command "zdColChange fill $win fill $cl" \
 	  -relief raised 
 	pack $win.oln.$cl -side left -expand 1 -fill both
 	pack $win.fill.$cl -side left -expand 1 -fill both
     }
 }
-} {
-proc clButtons win {
-    foreach cl {none black white red orange yellow green blue violet} {
-	set ccl [capitalise $cl]
-	button $win.oln.$cl -text $ccl -width 6 \
-	  -command "zdColChange ZDOln $win oln $cl" \
-	  -relief raised
-	button $win.fill.$cl -text $ccl -width 6 \
-	  -command "zdColChange ZDFill $win fill $cl" \
-	  -relief raised 
-	pack $win.oln.$cl -side left -expand 1 -fill both
-	pack $win.fill.$cl -side left -expand 1 -fill both
-    }
-}
-}
-
+#
 proc zdColChange {var win frame cl} {
-    global $var
-    if [info exists ${var}($win)] {
-	$win.$frame.[set ${var}($win)] configure -relief raised
+    upvar #0 Z$win zdata
+    if [info exists zdata($var)] {
+	$win.$frame.$zdata($var) configure -relief raised
     }
-    set ${var}($win) $cl
+    set zdata($var) $cl
     $win.$frame.$cl configure -relief sunken
 }
 #
 proc channel_zClearAll {this} {
-    if {[$this operator]} { $this zdDo delete *ALL*  } { $this zdClear }
+    if [$this operator] { $this zdDo delete *ALL*  } { $this zdClear }
 }
 #
 proc channel_makeZDraw {this} {
@@ -120,7 +92,8 @@ proc channel_makeZDraw {this} {
     set chan [$this name]
     toplevel $win -class Zircon
     wm title $win "${chan} Sketch Pad"
-    wm minsize $win 100 100
+    wm resizable $win 1 1
+    wm protocol $win WM_DELETE_WINDOW "zdDestroy $win"
     set f0 [frame $win.btn -relief raised]
     button $f0.save -text Save
     button $f0.print -text Print -command "$this zdPrint"
@@ -128,7 +101,7 @@ proc channel_makeZDraw {this} {
     bind $f0.clear <Shift-ButtonRelease-1> "
 	set sc \[lindex \[%W configure -command\] 4\]
 	%W configure -command {}
-	tk_butUp %W
+	tkButtonUp %W
 	uplevel #0 $this zClearAll
 	%W configure -command \$sc
     "
@@ -163,8 +136,8 @@ proc channel_makeZDraw {this} {
     pack $win.pic -expand 1 -fill both
     pack $win.hsFrm -fill x
     zdModeChange line $win
-    zdColChange ZDOln $win oln black
-    zdColChange ZDFill $win fill black
+    zdColChange oln $win oln black
+    zdColChange fill $win fill black
     bind $f1.canvas <1> " $this zdPress 1 %x %y "
     bind $f1.canvas <Double-1> "$this zdDouble 1 %x %y "
     bind $f1.canvas <B1-Motion> { zdMove %W 1 %x %y }
@@ -172,18 +145,19 @@ proc channel_makeZDraw {this} {
 }
 
 proc channel_zdPrint {this} {
-    .@zd${this}.pic.canvas postscript -file /tmp/[$this name].ps
+    .@zd$this.pic.canvas postscript -file /tmp/[$this name].ps
 }
 
 proc channel_zdSave {this chan} {
-    mkFileBox .@zs$this "Save Sketch ${chan}" {}\
-      "Save ${chan} sketch pad to:" \
-      "OK {.@zd${this}.pic.canvas postscript -file }" \
-      {Cancel {}}
+    global ztrans
+    mkFileBox .@zs$this .* ${this}(drawdir) "Save Sketch $chan" {}\
+      "Save $chan sketch pad to:" \
+      "$ztrans(ok) {.@zd$this.pic.canvas postscript -file }" \
+      "$ztrans(cancel) {}"
 }
 
 proc channel_zdDo {this args} {
-    global myid
+    set myid [[$this net] myid]
     set w .@zd$this.pic.canvas
     switch [lindex $args 0] {
     delete {
@@ -198,125 +172,124 @@ proc channel_zdDo {this args} {
 	}
     }
     set chan2 [expr {[$this isa Channel] ? [$this name] : [$myid name]}]
-    sendCtcp ZIRCON [$this name] "DRAW ${chan2} [join $args]"
+    [$this net] CTCP ZIRCON [$this name] "DRAW ${chan2} [join $args]"
 }
-
+#
 proc channel_zdClear {this} {
-    global myid
-    $this zdDo delete [$myid name]
+    $this zdDo delete [[$this net] nickname]
 }
-
+#
+proc checkNone {val} { return [expr {$val == {none} ? {{}} : $val}] }
+#
 proc channel_zdPress {this btn x y} {
-    global ZDMode ZDStart ZDLast
     set w .@zd$this
-    set can .@zd${this}.pic.canvas
+    upvar #0 Z$w zdata
+    set can $w.pic.canvas
     set x [$can canvasx $x]
     set y [$can canvasy $y]
-    if [string match {} $ZDStart($w)] {
-	set ZDLast($w) [set ZDStart($w) [list $x $y]]
+    if [string match {} $zdata(start)] {
+	set zdata(last) [set zdata(start) [list $x $y]]
 	return
     }
-    global ZDFill ZDOln
-    if [string match {none} [set fill $ZDFill($w)]] {set fill {{}}}
-    if [string match {none} [set oln $ZDOln($w)]] {set oln {{}} }
-    switch -exact -- $ZDMode($w) {
+    set fill [checkNone $zdata(fill)]
+    set oln [checkNone $zdata(oln)]
+    switch -exact -- $zdata(mode) {
     arc -
     oval -
     rectangle {
-	    $this zdDo create $ZDMode($w) [join $ZDStart($w)] $x $y \
+	    $this zdDo create $zdata(mode) [join $zdata(start)] $x $y \
 	    -fill $fill -outline $oln
-	    set ZDLast($w) [set ZDStart($w) {}]
+	    set zdata(last) [set zdata(start) {}]
 	}
     line {
-	    $this zdDo create $ZDMode($w) [join $ZDStart($w)] $x $y \
-	    -fill $oln
-	    set ZDLast($w) [set ZDStart($w) {}]
+	    $this zdDo create $zdata(mode) [join $zdata(start)] $x $y \
+	      -fill $oln
+	    set zdata(last) [set zdata(start) {}]
 	}
     polygon {
-	    eval ${w}.pic.canvas create line [join $ZDLast($w)] $x $y \
+	    eval ${w}.pic.canvas create line [join $zdata(last)] $x $y \
 	      -tags @p -fill $oln
-	    global ZDPoints
-	    lappend ZDPoints($w) "$x $y"
-	    set ZDLast($w) [list $x $y]
+	    lappend zdata(points) "$x $y"
+	    set zdata(last) [list $x $y]
 	}
     text {
+	    global ztrans
 	    mkEntryBox .@[newName text] Text {Enter your text:} \
-	       {{Text {}}} "OK {zAddText $this $w $x $y}" {Cancel {}}
+	      "{$ztrans(text) {}}" "$ztrans(ok) {zAddText $this $w $x $y}" \
+	      "$ztrans(cancel) {}"
 	}
     }
 }
 #
 proc zAddText {this w x y txt} {
-    global ZDOln ZDFill
-    set can .@zd${this}.pic.canvas
+    upvar #0 Z$w zdata
+    set can .@zd$this.pic.canvas
     set x [$can canvasx $x]
     set y [$can canvasy $y]
-#    if [string match {none} [set oln $ZDOln($w)]] {set oln {{}} }
-    if ![string match {none} [set fill $ZDFill($w)]] {
+#    if [string match {none} [set oln $zdata(oln)]] {set oln {{}} }
+    if ![string match {none} [set fill $zdata(fill)]] {
 	$this zdDo create text $x $y -text "{$txt}" -fill $fill
     }
 }
 #
 proc zdMove {win btn x y} {
-    global ZDStart
     set w [winfo toplevel $win]
+    upvar #0 Z$w zdata
     set can $w.pic.canvas
     set x [$can canvasx $x]
     set y [$can canvasy $y]
-    if {[string match {} $ZDStart($w)] || $ZDStart($w) == [list $x $y]} { return }
-    global ZDMode ZDLast ZDFill ZDOln
-    if [string match {none} [set fill $ZDFill($w)]] {set fill {{}}}
-    if [string match {none} [set oln $ZDOln($w)]] {set oln {{}} }
+    if {[string match {} $zdata(start)] || $zdata(start) == [list $x $y]} return
+    set fill [checkNone $zdata(fill)]
+    set oln [checkNone $zdata(oln)]
     $win delete @r
-    switch -exact -- $ZDMode($w) {
+    switch -exact -- $zdata(mode) {
     arc -
     oval -
     rectangle {
-	    eval ${win} create $ZDMode($w) [join $ZDStart($w)] $x $y \
+	    eval ${win} create $zdata(mode) [join $zdata(start)] $x $y \
 	      -tags @r -fill $fill -outline $oln
 	}
     line {
-	    eval ${win} create line [join $ZDStart($w)] $x $y \
+	    eval ${win} create line [join $zdata(start)] $x $y \
 	      -tags @r -fill $oln
 	}
     polygon {
-	    eval ${win} create line [join $ZDLast($w)] $x $y -tags @r \
+	    eval ${win} create line [join $zdata(last)] $x $y -tags @r \
 	      -fill $oln
 	}
     text {
 	}   
     }
 }
-
+#
 proc channel_zdUp {this btn x y} {
-    global ZDMode ZDStart
     set w .@zd$this
-    set can .@zd${this}.pic.canvas
+    upvar #0 Z$w zdata
+    set can .@zd$this.pic.canvas
     set x [$can canvasx $x]
     set y [$can canvasy $y]
-    if {![string match "" $ZDStart($w)] && $ZDStart($w) != [list $x $y]} {
-	global ZDLast ZDFill ZDOln
-	if [string match {none} [set fill $ZDFill($w)]] {set fill {{}}}
-	if [string match {none} [set oln $ZDOln($w)]] {set oln {{}} }
+    if {![string match {} $zdata(start)] && $zdata(start) != [list $x $y]} {
+	set fill [checkNone $zdata(fill)]
+	set oln [checkNone $zdata(oln)]
 	set win $w.pic.canvas
 	$win delete @r
-	switch -exact -- $ZDMode($w) {
+	switch -exact -- $zdata(mode) {
 	arc -
 	oval -
 	rectangle {
-		$this zdDo create $ZDMode($w) [join $ZDStart($w)] $x $y \
+		$this zdDo create $zdata(mode) [join $zdata(start)] $x $y \
 		  -fill $fill -outline $oln
-		set ZDLast($w) [set ZDStart($w) {}]
+		set zdata(last) [set zdata(start) {}]
 	    }
 	line {
-		$this zdDo create $ZDMode($w) [join $ZDStart($w)] $x $y \
+		$this zdDo create $zdata(mode) [join $zdata(start)] $x $y \
 		  -fill $oln
-		set ZDLast($w) [set ZDStart($w) {}]
+		set zdata(last) [set zdata(start) {}]
 	    }
 	polygon {
-		eval ${win} create line [join $ZDLast($w)] $x $y -tags @r \
+		eval ${win} create line [join $zdata(last)] $x $y -tags @r \
 		  -fill $oln
-		set ZDLast($w) [list $x $y]
+		set zdata(last) [list $x $y]
 	    }
 	text {
 	    }    
@@ -325,43 +298,41 @@ proc channel_zdUp {this btn x y} {
 }
 
 proc channel_zdDouble {this btn x y} {
-    global ZDMode ZDStart ZDLast
     set w .@zd$this
-    set can .@zd${this}.pic.canvas
+    upvar #0 Z$w zdata
+    set can $w.pic.canvas
     set x [$can canvasx $x]
     set y [$can canvasy $y]
-    if [string match "" $ZDStart($w)] {
-	set ZDLast($w) [set ZDStart($w) [list $x $y]]
+    if [string match {} $zdata(start)] {
+	set zdata(last) [set zdata(start) [list $x $y]]
 	return
     }
-    global ZDFill ZDOln
-    if [string match {none} [set fill $ZDFill($w)]] {set fill {{}}}
-    if [string match {none} [set oln $ZDOln($w)]] {set oln {{}} }
-    switch -exact -- $ZDMode($w) {
+    set fill [checkNone $zdata(fill)]
+    set oln [checkNone $zdata(oln)]
+    switch -exact -- $zdata(mode) {
     arc -
     oval -
     rectangle {
-	    $this zdDo create $ZDMode($w) [join $ZDStart($w)] $x $y \
+	    $this zdDo create $zdata(mode) [join $zdata(start)] $x $y \
 	      -fill $fill -outline $oln
-	    set ZDLast($w) [set ZDStart($w) {}]
+	    set zdata(last) [set zdata(start) {}]
 	}
     line {
-	    $this zdDo create $ZDMode($w) [join $ZDStart($w)] $x $y \
+	    $this zdDo create $zdata(mode) [join $zdata(start)] $x $y \
 	      -fill $oln
-	    set ZDLast($w) [set ZDStart($w) {}]
+	    set zdata(last) [set zdata(start) {}]
 	}
     polygon {
-	    global ZDPoints
-	    $this zdDo create polygon [join $ZDStart($w)] \
-	      [join $ZDPoints($w)] $x $y -fill $fill
+	    $this zdDo create polygon [join $zdata(start)] \
+	      [join $zdata(points)] $x $y -fill $fill
 	    ${w}.pic.canvas delete @p
 	    if {$oln != {{}}} {
-		$this zdDo create line [join $ZDStart($w)] \
-		  [join $ZDPoints($w)] $x $y [join $ZDStart($w)] \
+		$this zdDo create line [join $zdata(start)] \
+		  [join $zdata(points)] $x $y [join $zdata(start)] \
 		  -fill $oln
 	    }
-	    set ZDPoints($w) {}
-	    set ZDLast($w) [set ZDStart($w) {}]
+	    set zdata(points) {}
+	    set zdata(last) [set zdata(start) {}]
 	}
     text {
 	}
